import { AbstractLocalNotifications, debug as abstractDebug, } from './local-notifications.abstract';
/* Prefix debug and error output with '(ios)' */
const debug = abstractDebug.bind(null, '(ios)');
var LocalNotificationsDelegate = /** @class */ (function (_super) {
    __extends(LocalNotificationsDelegate, _super);
    function LocalNotificationsDelegate(notificationHandler) {
        var _this = _super.call(this) || this;
        debug('Constructed delegate', !!notificationHandler);
        _this._notificationHandler = notificationHandler;
        return _this;
    }
    LocalNotificationsDelegate.prototype.userNotificationCenterDidReceiveNotificationResponseWithCompletionHandler = function (center, response, completionHandler) {
        var _a;
        debug('Handling notification', response.notification.request.identifier);
        var notification = {
            id: response.notification.request.identifier,
            title: response.notification.request.content.title,
            message: response.notification.request.content.body,
        };
        var dictionary = response.notification.request.content.userInfo;
        if (dictionary) {
            var data = dictionary.valueForKey('data');
            if (data) {
                try {
                    notification.data = JSON.parse(data);
                }
                catch (error) {
                    console.log('Error parsing data for notification', notification.id, error);
                }
            }
        }
        try {
            (_a = this._notificationHandler) === null || _a === void 0 ? void 0 : _a.call(this, notification);
        }
        catch (error) {
            error('Error handling notification', notification.id, error);
        }
        completionHandler();
    };
    LocalNotificationsDelegate.prototype.userNotificationCenterWillPresentNotificationWithCompletionHandler = function (center, notification, completionHandler) {
        debug('Presenting notification', notification.request.identifier);
        completionHandler(UNNotificationPresentationOptions.Alert | UNNotificationPresentationOptions.Sound);
    };
    LocalNotificationsDelegate.ObjCProtocols = [UNUserNotificationCenterDelegate];
    return LocalNotificationsDelegate;
}(NSObject));
export class LocalNotifications extends AbstractLocalNotifications {
    constructor() {
        super();
        this.notificationCenter = UNUserNotificationCenter.currentNotificationCenter();
        this.notificationCenter.delegate = new LocalNotificationsDelegate(this._handler);
    }
    scheduleNative(notification, seconds) {
        return new Promise((resolve, reject) => {
            // eslint-disable-next-line new-cap
            const id = NSUUID.UUID().UUIDString.toUpperCase();
            // First of all we request the permission, before anything else...
            debug('Requesting permission for notification', id);
            this.notificationCenter.requestAuthorizationWithOptionsCompletionHandler(4 /* Alert */ | 2 /* Sound */, (result, error) => {
                if (error)
                    return reject(error);
                if (!result)
                    return reject(new Error('Local Notification authorization request denied'));
                const { title, message } = notification;
                const content = UNMutableNotificationContent.new();
                content.title = title;
                content.body = message;
                const data = JSON.stringify(notification.data || {});
                content.userInfo = NSDictionary.dictionaryWithObjectsForKeys([data], ['data']);
                const trigger = UNTimeIntervalNotificationTrigger.triggerWithTimeIntervalRepeats(seconds, false);
                const request = UNNotificationRequest.requestWithIdentifierContentTrigger(id, content, trigger);
                debug('Scheduling notification', id, 'in', seconds, 'sec.');
                this.notificationCenter.addNotificationRequestWithCompletionHandler(request, (error) => {
                    if (error)
                        return reject(error);
                    return resolve(id);
                });
            });
        });
    }
    cancel(id) {
        return new Promise((resolve) => {
            debug('Removing notification', id);
            this.notificationCenter.removePendingNotificationRequestsWithIdentifiers([id]);
            resolve();
        });
    }
}
//# sourceMappingURL=local-notifications.ios.js.map